//
//  FireworkSdk+EventTracking.swift
//  react-native-firework-sdk
//
//  Created by Jeff Zheng on 2021/12/21.
//

import FireworkVideo
import Foundation

extension FireworkSDKModulePlugin: FireworkVideoPlaybackDelegate {
    func fireworkVideoDidPause(_ videoPlayback: VideoPlaybackDetails) {

    }

    func fireworkVideoDidResume(_ videoPlayback: VideoPlaybackDetails) {

    }

    func fireworkVideoDidRecordImpression(_ videoPlayback: VideoPlaybackDetails) {
        guard enableVideoPlayBackEvent else { return }

        channel.invokeMethod(
            FWEventName.videoPlayback.rawValue,
            arguments: [
                "eventName": VideoPlaybackSubEventName.impression.rawValue,
                "info": videoPlayback.jsObject
            ])
    }

    func fireworkVideoDidStartPlaying(_ videoPlayback: VideoPlaybackDetails) {
        guard enableVideoPlayBackEvent else { return }

        channel.invokeMethod(
            FWEventName.videoPlayback.rawValue,
            arguments: [
                "eventName": VideoPlaybackSubEventName.start.rawValue,
                "info": videoPlayback.jsObject
            ])
    }

    func fireworkVideoReachedFirstQuartile(_ videoPlayback: VideoPlaybackDetails) {
        guard enableVideoPlayBackEvent else { return }

        channel.invokeMethod(
            FWEventName.videoPlayback.rawValue,
            arguments: [
                "eventName": VideoPlaybackSubEventName.firstQuartile.rawValue,
                "info": videoPlayback.jsObject
            ])
    }

    func fireworkVideoReachedMidPoint(_ videoPlayback: VideoPlaybackDetails) {
        guard enableVideoPlayBackEvent else { return }

        channel.invokeMethod(
            FWEventName.videoPlayback.rawValue,
            arguments: [
                "eventName": VideoPlaybackSubEventName.midpoint.rawValue,
                "info": videoPlayback.jsObject
            ])
    }

    func fireworkVideoReachedThirdQuartile(_ videoPlayback: VideoPlaybackDetails) {
        guard enableVideoPlayBackEvent else { return }

        channel.invokeMethod(
            FWEventName.videoPlayback.rawValue,
            arguments: [
                "eventName": VideoPlaybackSubEventName.thirdQuartile.rawValue,
                "info": videoPlayback.jsObject
            ])
    }

    func fireworkVideoDidFinishPlaying(_ videoPlayback: VideoPlaybackDetails) {
        guard enableVideoPlayBackEvent else { return }

        channel.invokeMethod(
            FWEventName.videoPlayback.rawValue,
            arguments: [
                "eventName": VideoPlaybackSubEventName.complete.rawValue,
                "info": videoPlayback.jsObject
            ])
    }

    func fireworkVideoDidTapCTAButton(_ videoPlayback: VideoPlaybackDetails) {
        guard enableVideoPlayBackEvent else { return }

        channel.invokeMethod(
            FWEventName.videoPlayback.rawValue,
            arguments: [
                "eventName": VideoPlaybackSubEventName.clickCTA.rawValue,
                "info": videoPlayback.jsObject
            ])
    }

    func fireworkVideoDidTapShareButton(_ videoPlayback: VideoPlaybackDetails) {
        guard enableVideoPlayBackEvent else { return }

        channel.invokeMethod(
            FWEventName.videoPlayback.rawValue,
            arguments: [
                "eventName": VideoPlaybackSubEventName.clickShare.rawValue,
                "info": videoPlayback.jsObject
            ])
    }

    func fireworkVideoDidStartPlayingAd(_ videoPlayback: VideoPlaybackDetails) {

    }

    func fireworkVideoDidFinishPlayingAd(_ videoPlayback: VideoPlaybackDetails) {
        guard enableVideoPlayBackEvent else { return }

        channel.invokeMethod(
            FWEventName.videoPlayback.rawValue,
            arguments: [
                "eventName": VideoPlaybackSubEventName.adEnd.rawValue,
                "info": videoPlayback.jsObject
            ])
    }
}

extension FireworkSDKModulePlugin: FireworkVideoFeedDelegate {

    func fireworkVideoDidTapThumbnail(_ eventDetails: FeedEventDetails) {
        channel.invokeMethod(
            FWEventName.videoFeedClick.rawValue, arguments: ["info": eventDetails.jsObject])
    }
}
