//
//  LiveStreamModule.swift
//  react-native-firework-sdk
//
//  Created by Jeff Zheng on 2022/2/16.
//

import FireworkVideo
import Foundation

@objc(LiveStreamModule)
class LiveStreamModulePlugin: NSObject, FlutterPlugin, FireworkLiveStreamEventDelegate {
    var channel: FlutterMethodChannel! = nil

    static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(
            name: FWChannelName.fireworkLiveStreamModule.rawValue,
            binaryMessenger: registrar.messenger())
        let instance = LiveStreamModulePlugin()
        instance.channel = channel
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case FWLiveStreamMethodName.`init`.rawValue:
            initialize()
            result(nil)
        default:
            result(FlutterMethodNotImplemented)
        }
    }

    func initialize() {
        DispatchQueue.once {
            FireworkVideoSDK.eventTracking.liveStreamEventDelegate = self
        }
    }

    func fireworkLiveStreamUserDidJoin(_ liveStream: LiveStreamEventDetails) {
        channel.invokeMethod(
            LiveStreamEventName.livestream.rawValue,
            arguments: [
                "eventName": LiveStreamSubEventName.userDidjoin.rawValue,
                "info": liveStream.jsObject
            ]
        )
    }

    func fireworkLiveStreamUserDidLeave(_ liveStream: LiveStreamEventDetails) {
        channel.invokeMethod(
            LiveStreamEventName.livestream.rawValue,
            arguments: [
                "eventName": LiveStreamSubEventName.userDidLeave.rawValue,
                "info": liveStream.jsObject
            ]
        )
    }

    func fireworkLiveStreamUserDidSendChat(
        _ message: LiveStreamMessageDetails, to liveStream: LiveStreamEventDetails
    ) {
        channel.invokeMethod(
            LiveStreamEventName.livestreamChat.rawValue,
            arguments: [
                "eventName": LiveStreamChatSubEventName.userSendChat.rawValue,
                "message": message.jsObject,
                "liveStream": liveStream.jsObject
            ]
        )
    }

    func fireworkLiveStreamUserDidSendLike(_ liveStream: LiveStreamEventDetails) {
        channel.invokeMethod(
            LiveStreamEventName.livestream.rawValue,
            arguments: [
                "eventName": LiveStreamSubEventName.userSendLike.rawValue,
                "info": liveStream.jsObject
            ]
        )
    }
}
