//
//  FireworkNavigatorModule.swift
//  fw_flutter_sdk
//
//  Created by Jeff Zheng on 2022/4/18.
//

import FireworkVideo
import Flutter
import Foundation
import UIKit

class FireworkNavigatorModule: NSObject, FlutterPlugin {
    var channel: FlutterMethodChannel! = nil

    static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(
            name: FWChannelName.fireworkNavigatorModule.rawValue,
            binaryMessenger: registrar.messenger())
        let instance = FireworkNavigatorModule()
        instance.channel = channel
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case FWNavigatorModuleMethodName.pushNativeContainer.rawValue:
            pushNativeContainer(call.arguments as? [String: Any], result: result)
        case FWNavigatorModuleMethodName.popNativeContainer.rawValue:
            popNativeContainer(result: result)
        case FWNavigatorModuleMethodName.canPopNativeContainer.rawValue:
            canPopNativeContainer(result: result)
        default:
            result(FlutterMethodNotImplemented)
        }
    }

    func pushNativeContainer(_ initialize: [String: Any]?, result: @escaping FlutterResult) {
        guard let navigatorPageProvider = SwiftFireworkFlutterSdkPlugin.navigatorPageProvider else {
            print("Not implement navigatorPageProvider!")
            result(false)
            return
        }

        guard let presentedVC = UIViewController.presentedViewController() else {
            print("Not found top presented view controller!")
            result(false)
            return
        }

        guard let flutterVC = navigatorPageProvider(initialize) else {
            print("The returned flutter view controller is nil!")
            result(false)
            return
        }
        flutterVC.modalPresentationStyle = .fullScreen
        if presentedVC.modalPresentationStyle == .custom,
            let presentingVC = presentedVC.presentingViewController,
            presentingVC is FireworkVideo.PlayerViewController {
            flutterVC.modalPresentationStyle = .overFullScreen
        }

        presentedVC.present(flutterVC, animated: true) {
            result(true)
        }
    }

    func popNativeContainer(result: @escaping FlutterResult) {
        if let presentedVC = UIViewController.presentedViewController() as? FlutterViewController,
            presentedVC.presentingViewController != nil {
            presentedVC.dismiss(animated: true) {
                result(true)
            }
        } else if let cartViewController = ShoppingModulePlugin.cartViewController {
            cartViewController.navigationController?.popViewController(animated: true)
            ShoppingModulePlugin.cartViewController = nil
            result(true)
        } else if let presentedVC = UIViewController.presentedViewController(),
            let presentingVC = presentedVC.presentingViewController,
                  presentingVC.presentingViewController == UIApplication.shared.keyWindow?.rootViewController {
            NotificationCenter.default.post(name: gOnVideoTemporarilyReleasePipController, object: nil)
            FWNavigatorUtils.shared.shouldDisablePlay = true
            presentedVC.dismiss(animated: false) {
                DispatchQueue.main.asyncAfter(deadline: .now() + 0.1) {
                    presentingVC.dismiss(animated: true) {
                        NotificationCenter.default.post(name: gOnVideoRestorePipController, object: nil)
                        result(true)
                        FWNavigatorUtils.shared.shouldDisablePlay = false
                    }
                }
            }
        } else if let rootVC = UIApplication.shared.keyWindow?.rootViewController,
                  rootVC.presentedViewController != nil {
            NotificationCenter.default.post(name: gOnVideoTemporarilyReleasePipController, object: nil)
            rootVC.dismiss(animated: true) {
                NotificationCenter.default.post(name: gOnVideoRestorePipController, object: nil)
                result(true)
            }
        } else {
            result(false)
        }
    }

    func canPopNativeContainer(result: @escaping FlutterResult) {
        if let presentedVC = UIViewController.presentedViewController(),
            presentedVC.presentingViewController != nil {
            result(true)
        } else if ShoppingModulePlugin.cartViewController != nil {
            result(true)
        } else {
            result(false)
        }
    }
}
