//
//  CartViewController.swift
//  react-native-firework-sdk
//
//  Created by Jeff Zheng on 2021/12/31.
//

import FireworkVideo
import Flutter
import UIKit

@objc(FWCartViewController)
public class FWCartViewController: UIViewController, CartViewRepresentable {
    @objc public var showCustomCartView: Bool = true
    init(showCustomCartView: Bool) {
        super.init(nibName: nil, bundle: nil)
        self.showCustomCartView = showCustomCartView
    }

    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }

    public override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        if showCustomCartView {
            self.navigationController?.setNavigationBarHidden(true, animated: true)
        }
    }

    public override func viewDidLoad() {
        super.viewDidLoad()
        if showCustomCartView {
            directShowCustomCartView()
        }
    }

    public override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        if showCustomCartView {
            self.navigationController?.setNavigationBarHidden(false, animated: true)
        }
    }

    private func directShowCustomCartView() {

        guard let customCartPageProvider = SwiftFireworkFlutterSdkPlugin.customCartPageProvider
        else {
            print("Not implement customCartPageProvdier!")
            return
        }

        let flutterVC = customCartPageProvider()
        let flutterRootView: UIView! = flutterVC.view
        flutterRootView.translatesAutoresizingMaskIntoConstraints = false

        self.addChild(flutterVC)
        view.addSubview(flutterRootView)
        NSLayoutConstraint.activate([
            flutterRootView.leftAnchor.constraint(equalTo: view.leftAnchor),
            flutterRootView.topAnchor.constraint(equalTo: view.topAnchor),
            flutterRootView.rightAnchor.constraint(equalTo: view.rightAnchor),
            flutterRootView.bottomAnchor.constraint(equalTo: view.bottomAnchor)
        ])

        flutterVC.didMove(toParent: self)
    }
}
