//
//  StoryBlock.swift
//  fw_flutter_sdk
//
//  Created by linjie jiang on 2022/8/10.
//

import FireworkVideo
import UIKit

@objc
public enum StoryBlockSourceType: Int {
    case discover, channel, playlist, dynamicContent
}

public protocol StoryBlockViewDelegate: AnyObject {
    func storyBlockDidLoadFeed(_ view: StoryBlock)
    func storyBlock(_ view: StoryBlock, didFailToLoadFeed error: StoryBlockError)
}

@objc
public class StoryBlock: UIView, StoryBlockViewControllerDelegate {
    @objc public var sourceType: StoryBlockSourceType = .discover
    @objc public var channel: String = ""
    @objc public var playlist: String = ""
    @objc public var dynamicContentParameters: [String: [String]] = [:]
    @objc public var enablePictureInPicture: Bool = false

    public weak var delegate: StoryBlockViewDelegate?

    private var storyBlockVC: StoryBlockViewController?

    private var source: StoryBlockContentSource {
        switch sourceType {
        case .discover:
            return .discover
        case .channel:
            return .channel(channelID: channel)
        case .playlist:
            return .channelPlaylist(channelID: channel, playlistID: playlist)
        case .dynamicContent:
            return .dynamicContent(channelID: channel, parameters: dynamicContentParameters)
        }
    }

    private var pipController: PictureInPictureController?

    public override func layoutSubviews() {
        super.layoutSubviews()

        embed()
    }

    private func embed() {
        guard let parentVC = parentViewController else {
            return
        }
        guard self.storyBlockVC == nil else {
            return
        }

        let storyBlockVC = StoryBlockViewController(source: source)
        if self.enablePictureInPicture {
            self.pipController = PictureInPictureController(storyBlock: storyBlockVC)
        } else {
            self.pipController = nil
        }

        storyBlockVC.delegate = self
        self.storyBlockVC = storyBlockVC
        parentVC.attachChild(storyBlockVC, to: self)
    }

    public override func removeFromSuperview() {
        super.removeFromSuperview()
        self.pipController = nil

        guard let storyBlockVC = self.storyBlockVC else {
            return
        }

        storyBlockVC.detachFromParent()
        self.storyBlockVC = nil
    }

    public func storyBlockDidLoadFeed(_ viewController: StoryBlockViewController) {
        guard let delegate = self.delegate else {
            return
        }

        delegate.storyBlockDidLoadFeed(self)
    }

    public func storyBlock(
        _ viewController: StoryBlockViewController, didFailToLoadFeed error: StoryBlockError
    ) {
        guard let delegate = self.delegate else {
            return
        }

        delegate.storyBlock(self, didFailToLoadFeed: error)
    }
}
