//
//  UIViewController+FWSwizzle.m
//  FireworkSdk
//
//  Created by linjie jiang on 2022/9/8.
//

#import "UINavigationController+FWSwizzle.h"
#import <objc/runtime.h>
#if __has_include(<fw_flutter_sdk/fw_flutter_sdk-Swift.h>)
#import <fw_flutter_sdk/fw_flutter_sdk-Swift.h>
#else
// Support project import fallback if the generated compatibility header
// is not copied when this plugin is created as a library.
// https://forums.swift.org/t/swift-static-libraries-dont-copy-generated-objective-c-header/19816
#import "fw_flutter_sdk-Swift.h"
#endif

@implementation UINavigationController (FWSwizzle)

+ (void)load {
    static dispatch_once_t once_token;
    dispatch_once(&once_token, ^{
        Class class = [self class];
        SEL defaultSelector = @selector(pushViewController:animated:);
        SEL swizzledSelector = @selector(_fw_pushViewController:animated:);
        Method defaultMethod =
            class_getInstanceMethod(class, defaultSelector);
        Method swizzledMethod =
            class_getInstanceMethod(class, swizzledSelector);
        BOOL isMethodExists =
            !class_addMethod(class, defaultSelector,
                method_getImplementation(swizzledMethod),
                method_getTypeEncoding(swizzledMethod));
        if (isMethodExists) {
            method_exchangeImplementations(defaultMethod, swizzledMethod);
        } else {
            class_replaceMethod(class, swizzledSelector,
                method_getImplementation(defaultMethod),
                method_getTypeEncoding(defaultMethod));
            }
    });
}

- (void)_fw_pushViewController:(UIViewController *)viewController animated:(BOOL)animated {
    if ([viewController isKindOfClass:[FWCartViewController class]]) {
        FWCartViewController *cartVC = (FWCartViewController *)viewController;
        if (!cartVC.showCustomCartView) {
            return;
        }
    }
    [self _fw_pushViewController:viewController animated:animated];
}

@end
