class VideoFeedConfiguration {
  /// The background color of video feed.
  String? backgroundColor;

  /// The corner radius of video feed. Only supported on iOS.
  double? cornerRadius;

  /// The configuration of video feed title.
  VideoFeedTitleConfiguration? title;

  /// The title position of video feed.
  VideoFeedTitlePosition? titlePosition;

  /// The configuration of video feed play icon. Only supported on iOS.
  VideoFeedPlayIconConfiguration? playIcon;

  /// Indicates if the video feed shows ad badge.
  bool? showAdBadge;

  /// Custom layout name for video feed item. Only supported on Android.
  String? customLayoutName;

  /// The aspect ratio(width / height) for video feed item. Only supported on iOS.
  double? aspectRatio;

  /// The content padding for video feed. Only supported on iOS.
  VideoFeedContentPadding? contentPadding;

  /// The item spacing for video feed. Only supported on iOS.
  double? itemSpacing;

  /// Specifies if autoplay is enabled.
  bool? enableAutoplay;

  /// The number of feed items to be displayed per row.
  /// The property only takes effect when video feed mode is grid.
  /// The property value needs to be greater than 0.
  int? gridColumns;

  /// Specifies if Picture in Picture is enabled. Only supported on iOS.
  bool? enablePictureInPicture;

  VideoFeedConfiguration({
    this.backgroundColor,
    this.cornerRadius,
    this.title,
    this.titlePosition,
    this.playIcon,
    this.showAdBadge,
    this.customLayoutName,
    this.aspectRatio,
    this.contentPadding,
    this.itemSpacing,
    this.enableAutoplay,
    this.gridColumns,
    this.enablePictureInPicture,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedConfiguration) {
      return backgroundColor == other.backgroundColor &&
          cornerRadius == other.cornerRadius &&
          title == other.title &&
          titlePosition == other.titlePosition &&
          playIcon == other.playIcon &&
          showAdBadge == other.showAdBadge &&
          customLayoutName == other.customLayoutName &&
          aspectRatio == other.aspectRatio &&
          contentPadding == other.contentPadding &&
          itemSpacing == other.itemSpacing &&
          enableAutoplay == other.enableAutoplay &&
          gridColumns == other.gridColumns &&
          enablePictureInPicture == other.enablePictureInPicture;
    }

    return false;
  }

  @override
  int get hashCode =>
      backgroundColor.hashCode ^
      cornerRadius.hashCode ^
      title.hashCode ^
      titlePosition.hashCode ^
      playIcon.hashCode ^
      showAdBadge.hashCode ^
      customLayoutName.hashCode ^
      aspectRatio.hashCode ^
      contentPadding.hashCode ^
      itemSpacing.hashCode ^
      enableAutoplay.hashCode ^
      gridColumns.hashCode ^
      enablePictureInPicture.hashCode;
}

class VideoFeedPlayIconConfiguration {
  bool? hidden;
  double? iconWidth;

  VideoFeedPlayIconConfiguration({
    this.hidden,
    this.iconWidth,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedPlayIconConfiguration) {
      return hidden == other.hidden && iconWidth == other.iconWidth;
    }

    return false;
  }

  @override
  int get hashCode => hidden.hashCode ^ iconWidth.hashCode;
}

class VideoFeedTitleConfiguration {
  bool? hidden;
  String? textColor;
  double? fontSize;

  VideoFeedTitleConfiguration({
    this.hidden,
    this.textColor,
    this.fontSize,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedTitleConfiguration) {
      return hidden == other.hidden &&
          textColor == other.textColor &&
          fontSize == other.fontSize;
    }

    return false;
  }

  @override
  int get hashCode => hidden.hashCode ^ textColor.hashCode ^ fontSize.hashCode;
}

enum VideoFeedTitlePosition {
  stacked,
  nested,
}

class VideoFeedContentPadding {
  double? top;
  double? right;
  double? bottom;
  double? left;

  VideoFeedContentPadding({
    this.top,
    this.right,
    this.bottom,
    this.left,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedContentPadding) {
      return top == other.top &&
          right == other.right &&
          bottom == other.bottom &&
          left == other.left;
    }

    return false;
  }

  @override
  int get hashCode =>
      top.hashCode ^ right.hashCode ^ bottom.hashCode ^ left.hashCode;
}
