enum VideoPlayerCompleteAction {
  loop,
  advanceToNext,
}

enum VideoLaunchBehavior {
  defaultBehavior,
  muteOnFirstLaunch,
}

class VideoPlayerConfiguration {
  /// Sets the proportion of the video player to its container.
  VideoPlayerStyle? playerStyle;

  /// Behavior occurring after video is complete.
  VideoPlayerCompleteAction? videoCompleteAction;

  /// Indicates if the video player shows share button.
  bool? showShareButton;

  /// The style of CTA button style. Only supported on iOS.
  VideoPlayerCTAStyle? ctaButtonStyle;

  /// Indicates if the video player shows playback button.
  bool? showPlaybackButton;

  /// Indicates if the video player shows mute button.
  bool? showMuteButton;

  /// Specifies the video player launch behavior.
  VideoLaunchBehavior? launchBehavior;

  /// Indicates if Firework branding should be showed or not.
  bool? showBranding;

  VideoPlayerConfiguration({
    this.playerStyle,
    this.videoCompleteAction,
    this.showShareButton,
    this.ctaButtonStyle,
    this.showPlaybackButton,
    this.showMuteButton,
    this.launchBehavior,
    this.showBranding,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoPlayerConfiguration) {
      return playerStyle == other.playerStyle &&
          videoCompleteAction == other.videoCompleteAction &&
          showShareButton == other.showShareButton &&
          ctaButtonStyle == other.ctaButtonStyle &&
          showPlaybackButton == other.showPlaybackButton &&
          showMuteButton == other.showMuteButton &&
          launchBehavior == other.launchBehavior &&
          showBranding == other.showBranding;
    }

    return false;
  }

  @override
  int get hashCode =>
      playerStyle.hashCode ^
      videoCompleteAction.hashCode ^
      showShareButton.hashCode ^
      ctaButtonStyle.hashCode ^
      showPlaybackButton.hashCode ^
      showMuteButton.hashCode ^
      launchBehavior.hashCode ^
      showBranding.hashCode;
}

class VideoPlayerCTAStyle {
  String? backgroundColor;
  String? textColor;
  double? fontSize;

  VideoPlayerCTAStyle({
    this.backgroundColor,
    this.textColor,
    this.fontSize,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoPlayerCTAStyle) {
      return backgroundColor == other.backgroundColor &&
          textColor == other.textColor &&
          fontSize == other.fontSize;
    }

    return false;
  }

  @override
  int get hashCode =>
      backgroundColor.hashCode ^ textColor.hashCode ^ fontSize.hashCode;
}

enum VideoPlayerStyle {
  full,
  fit,
}
