import 'dart:io';

import 'package:flutter/services.dart';

import '../../models/fw_method_name.dart';
import '../../utils/fw_method_channel_util.dart';
import '../../utils/model_utils/fw_error_util.dart';
import '../../utils/model_utils/fw_method_name_util.dart';
import 'story_block_platform_view.dart';

class StoryBlockPlatformHandler {
  final MethodChannel _channel;
  StoryBlockPlatformView _widget;

  StoryBlockPlatformHandler({
    required int viewId,
    required StoryBlockPlatformView widget,
  })  : _channel = FWMethodChannelUtil.getStoryBlockChannel(viewId),
        _widget = widget {
    _channel.setMethodCallHandler(_handleMethodCall);
  }

  void updateWidget(StoryBlockPlatformView widget) {
    _widget = widget;
  }

  Future<void> showFragment() async {
    if (Platform.isAndroid) {
      final nativeMethod = FWStoryBlockMethodNameUtil.convertToNativeMethod(
          FWStoryBlockNativeMethodName.showAndroidNativeFragment);
      await _channel.invokeMethod(nativeMethod);
    }
  }

  Future<dynamic> _handleMethodCall(MethodCall call) async {
    final methodName = FWStoryBlockMethodNameUtil.createMethodName(call.method);
    if (methodName == null) {
      return null;
    }

    switch (methodName) {
      case FWStoryBlockMethodName.onStoryBlockLoadFinished:
        final error = FWErrorUtil.fromJson(call.arguments);
        _widget.onStoryBlockPlatformViewLoadFinished?.call(error);
        break;
    }

    return null;
  }
}
