import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
// import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';

import '../../models/fw_error.dart';
import '../../models/story_block_source.dart';
import '../../utils/model_utils/story_block_source_util.dart';
import 'story_block_platform_handler.dart';

typedef StoryBlockPlatformViewLoadFinishedCallback = void Function(
    FWError? error);

class StoryBlockPlatformView extends StatefulWidget {
  final StoryBlockSource source;
  final String? channel;
  final String? playlist;
  final Map<String, List<String>>? dynamicContentParameters;
  final bool? enablePictureInPicture;
  final bool useHybridCompositionForAndroid;
  final StoryBlockPlatformViewLoadFinishedCallback?
      onStoryBlockPlatformViewLoadFinished;

  const StoryBlockPlatformView({
    Key? key,
    required this.source,
    this.channel,
    this.playlist,
    this.dynamicContentParameters,
    this.enablePictureInPicture,
    required this.useHybridCompositionForAndroid,
    this.onStoryBlockPlatformViewLoadFinished,
  }) : super(key: key);

  @override
  State<StoryBlockPlatformView> createState() => _StoryBlockPlatformViewState();
}

class _StoryBlockPlatformViewState extends State<StoryBlockPlatformView> {
  final String _viewType = "fw.fondor.view/story_block";
  StoryBlockPlatformHandler? _handler;

  @override
  void initState() {
    super.initState();
  }

  @override
  void didUpdateWidget(covariant StoryBlockPlatformView oldWidget) {
    super.didUpdateWidget(oldWidget);
    _handler?.updateWidget(widget);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return _buildAndroidPlatformView(context);
    } else {
      return _buildIOSPlatformView(context);
    }
  }

  Widget _buildAndroidPlatformView(BuildContext context) {
    return Container();
    // final creationParams = _generateCreationParams();
    // final layoutDirection =
    //     Directionality.maybeOf(context) ?? TextDirection.ltr;
    // const creationParamsCodec = StandardMessageCodec();

    // if (widget.useHybridCompositionForAndroid) {
    //   return PlatformViewLink(
    //     viewType: _viewType,
    //     surfaceFactory:
    //         (BuildContext context, PlatformViewController controller) {
    //       return AndroidViewSurface(
    //         controller: controller as AndroidViewController,
    //         gestureRecognizers: _generateGestureRecognizers(),
    //         hitTestBehavior: PlatformViewHitTestBehavior.opaque,
    //       );
    //     },
    //     onCreatePlatformView: (PlatformViewCreationParams params) {
    //       return PlatformViewsService.initSurfaceAndroidView(
    //         id: params.id,
    //         viewType: _viewType,
    //         layoutDirection: layoutDirection,
    //         creationParams: creationParams,
    //         creationParamsCodec: creationParamsCodec,
    //         onFocus: () {
    //           params.onFocusChanged(true);
    //         },
    //       )
    //         ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
    //         ..addOnPlatformViewCreatedListener(_onPlatformViewCreated)
    //         ..create();
    //     },
    //   );
    // } else {
    //   return AndroidView(
    //     viewType: _viewType,
    //     onPlatformViewCreated: _onPlatformViewCreated,
    //     layoutDirection: layoutDirection,
    //     creationParams: creationParams,
    //     creationParamsCodec: creationParamsCodec,
    //     gestureRecognizers: _generateGestureRecognizers(),
    //   );
    // }
  }

  Widget _buildIOSPlatformView(BuildContext context) {
    Map<String, dynamic> creationParams = _generateCreationParams();
    final layoutDirection =
        Directionality.maybeOf(context) ?? TextDirection.ltr;

    return UiKitView(
      viewType: _viewType,
      onPlatformViewCreated: _onPlatformViewCreated,
      layoutDirection: layoutDirection,
      creationParams: creationParams,
      creationParamsCodec: const StandardMessageCodec(),
      gestureRecognizers: _generateGestureRecognizers(),
    );
  }

  Map<String, dynamic> _generateCreationParams() {
    Map<String, dynamic> creationParams = <String, dynamic>{
      "source": StoryBlockSourceUtil.convertToRawFeedSource(widget.source),
    };

    if (widget.channel != null) {
      creationParams["channel"] = widget.channel!;
    }

    if (widget.playlist != null) {
      creationParams["playlist"] = widget.playlist!;
    }

    if (widget.dynamicContentParameters != null) {
      creationParams["dynamicContentParameters"] =
          widget.dynamicContentParameters!;
    }

    if (widget.enablePictureInPicture != null) {
      creationParams["enablePictureInPicture"] = widget.enablePictureInPicture!;
    }

    return creationParams;
  }

  Set<Factory<OneSequenceGestureRecognizer>> _generateGestureRecognizers() {
    return <Factory<OneSequenceGestureRecognizer>>{
      Factory<OneSequenceGestureRecognizer>(
        () => HorizontalDragGestureRecognizer(),
      ),
    };
  }

  void _onPlatformViewCreated(int viewId) {
    _handler = StoryBlockPlatformHandler(viewId: viewId, widget: widget);
    _handler?.showFragment();
  }
}
