import 'package:flutter_test/flutter_test.dart';
import 'package:fw_flutter_sdk/src/models/video_feed_source.dart';
import 'package:fw_flutter_sdk/src/utils/model_utils/feed_item_details_util.dart';

void main() {
  test('FeedItemDetailsUtil fromJson', () {
    final jsonForPlaylistFeed = <String, dynamic>{
      "source": "playlist",
      "id": "video_test_id",
      "index": 1,
      "duration": 100,
      "title": "test_title",
      "channel": "test_channel_id",
      "playlist": "test_playlist_id",
    };
    final itemForPlaylistFeed =
        FeedItemDetailsUtil.fromJson(jsonForPlaylistFeed);
    expect(itemForPlaylistFeed?.source, VideoFeedSource.playlist);
    expect(itemForPlaylistFeed?.id, jsonForPlaylistFeed["id"]);
    expect(itemForPlaylistFeed?.index, jsonForPlaylistFeed["index"]);
    expect(itemForPlaylistFeed?.duration, jsonForPlaylistFeed["duration"]);
    expect(itemForPlaylistFeed?.title, jsonForPlaylistFeed["title"]);
    expect(itemForPlaylistFeed?.channel, jsonForPlaylistFeed["channel"]);
    expect(itemForPlaylistFeed?.playlist, jsonForPlaylistFeed["playlist"]);

    final jsonForPlaylistGroupFeed = <String, dynamic>{
      "source": "playlistGroup",
      "id": "playlist_test_id",
      "index": 1,
      "duration": 100,
      "title": "test_title",
      "playlistGroup": "test_playlist_group_id",
    };
    final itemForPlaylistGroupFeed =
        FeedItemDetailsUtil.fromJson(jsonForPlaylistGroupFeed);
    expect(itemForPlaylistGroupFeed?.source, VideoFeedSource.playlistGroup);
    expect(itemForPlaylistGroupFeed?.id, jsonForPlaylistGroupFeed["id"]);
    expect(itemForPlaylistGroupFeed?.index, jsonForPlaylistGroupFeed["index"]);
    expect(itemForPlaylistGroupFeed?.duration,
        jsonForPlaylistGroupFeed["duration"]);
    expect(itemForPlaylistGroupFeed?.title, jsonForPlaylistGroupFeed["title"]);
    expect(itemForPlaylistGroupFeed?.playlistGroup,
        jsonForPlaylistGroupFeed["playlistGroup"]);

    final jsonForDynamicContentFeed = <String, dynamic>{
      "source": "dynamicContent",
      "id": "video_test_id",
      "index": 1,
      "duration": 100,
      "title": "test_title",
      "channel": "test_channel_id",
      "dynamicContentParameters": {
        "test_key": ["test_value1", "test_value2"]
      },
    };
    final itemForDynamicContentFeed =
        FeedItemDetailsUtil.fromJson(jsonForDynamicContentFeed);
    expect(itemForDynamicContentFeed?.source, VideoFeedSource.dynamicContent);
    expect(itemForDynamicContentFeed?.id, jsonForDynamicContentFeed["id"]);
    expect(
        itemForDynamicContentFeed?.index, jsonForDynamicContentFeed["index"]);
    expect(itemForDynamicContentFeed?.duration,
        jsonForDynamicContentFeed["duration"]);
    expect(
        itemForDynamicContentFeed?.title, jsonForDynamicContentFeed["title"]);
    expect(itemForDynamicContentFeed?.channel,
        jsonForDynamicContentFeed["channel"]);
    expect(itemForDynamicContentFeed?.dynamicContentParameters,
        jsonForDynamicContentFeed["dynamicContentParameters"]);
  });
}
