import 'package:flutter_test/flutter_test.dart';
import 'package:fw_flutter_sdk/src/models/fw_events.dart';
import 'package:fw_flutter_sdk/src/models/live_stream_event_details.dart';
import 'package:fw_flutter_sdk/src/models/live_stream_message_details.dart';
import 'package:fw_flutter_sdk/src/models/video_feed_source.dart';
import 'package:fw_flutter_sdk/src/models/video_playback_details.dart';
import 'package:fw_flutter_sdk/src/utils/model_utils/fw_events_util.dart';

void main() {
  test('SDKInitEventUtil fromJson', () {
    final json = {
      "error": {
        "name": "error_name",
        "reason": "error_reason",
      },
    };
    final event = SDKInitEventUtil.fromJson(json);
    expect(event?.error?.name, json["error"]?["name"]);
    expect(event?.error?.reason, json["error"]?["reason"]);
  });

  test('CustomCTAClickEventUtil fromJson', () {
    final json = {
      "url": "https://example.com",
    };
    final event = CustomCTAClickEventUtil.fromJson(json);
    expect(event?.url, json["url"]);
  });

  test('VideoPlaybackEventUtil fromJson', () {
    final playerSizeJson = {
      "width": 100,
      "height": 150,
    };
    final infoJson = {
      "videoId": "test_video_id",
      "duration": 100,
      "caption": "test_caption",
      "badge": "test_badge",
      "playerSize": playerSizeJson,
      "hasCTA": true,
    };
    final json = {
      "eventName": "fw:video:start",
      "info": infoJson,
    };
    final event = VideoPlaybackEventUtil.fromJson(json);
    expect(event?.eventName, VideoPlaybackEventName.start);
    expect(event?.info.videoId, infoJson["videoId"]);
    expect(event?.info.duration, infoJson["duration"]);
    expect(event?.info.caption, infoJson["caption"]);
    expect(event?.info.badge, infoJson["badge"]);
    expect(event?.info.playerSize?.width, playerSizeJson["width"]);
    expect(event?.info.playerSize?.height, playerSizeJson["height"]);
    expect(event?.info.hasCTA, infoJson["hasCTA"]);
  });

  test('VideoFeedClickEventUtil fromJson', () {
    final infoJson = <String, dynamic>{
      "source": "playlist",
      "id": "video_test_id",
      "index": 1,
      "duration": 100,
      "title": "test_title",
      "channel": "test_channel_id",
      "playlist": "test_playlist_id",
    };
    final json = {
      "info": infoJson,
    };
    final event = VideoFeedClickEventUtil.fromJson(json);
    expect(event?.info.source, VideoFeedSource.playlist);
    expect(event?.info.id, infoJson["id"]);
    expect(event?.info.index, infoJson["index"]);
    expect(event?.info.duration, infoJson["duration"]);
    expect(event?.info.title, infoJson["title"]);
    expect(event?.info.channel, infoJson["channel"]);
    expect(event?.info.playlist, infoJson["playlist"]);
  });

  test('AddToCartEventUtil fromJson', () {
    final json = {
      "productId": "test_product_id",
      "unitId": "test_unit_id",
    };
    final event = AddToCartEventUtil.fromJson(json);
    expect(event?.productId, json["productId"]);
    expect(event?.unitId, json["unitId"]);
  });

  test('UpdateProductDetailsEventUtil fromJson', () {
    final json = {
      "productIds": ["1", "2", "3"],
    };
    final event = UpdateProductDetailsEventUtil.fromJson(json);
    expect(event?.productIds, json["productIds"]);
  });

  test('WillDisplayProductEventUtil fromJson', () {
    final json = {
      "videoId": "test_video_id",
    };
    final event = WillDisplayProductEventUtil.fromJson(json);
    expect(event?.videoId, json["videoId"]);
  });

  test('FWEventUtil fromJson', () {
    final json = {
      "eventName": "test_event_name",
      "arguments": <String, dynamic>{
        "test_key": "test_value",
      }
    };
    final event = FWEventUtil.fromJson(json);
    expect(event?.eventName, json["eventName"]);
    expect(event?.arguments, json["arguments"]);
  });

  test('FWEventUtil toJson', () {
    final event = FWEvent(
      eventName: "test_event_name",
      arguments: <String, dynamic>{
        "test_key": "test_value",
      },
    );
    final json = FWEventUtil.toJson(event);
    expect(json["eventName"], event.eventName);
    expect(json["arguments"], event.arguments);
  });

  test('LiveStreamEventUtil fromJson', () {
    final infoJson = {
      "id": "test_id",
    };
    final json = {
      "eventName": "fw:livestream:user-join",
      "info": infoJson,
    };
    final event = LiveStreamEventUtil.fromJson(json);
    expect(event?.eventName, LiveStreamEventName.userDidjoin);
    expect(event?.info.id, infoJson["id"]);
  });

  test('LiveStreamChatEventUtil fromJson', () {
    final messageJson = {
      "messageId": "test_message_id",
      "username": "test_username",
      "text": "test_text",
    };
    final liveStreamJson = {
      "id": "test_id",
    };
    final json = {
      "eventName": "fw:livestream:user-send-chat",
      "message": messageJson,
      "liveStream": liveStreamJson,
    };
    final event = LiveStreamChatEventUtil.fromJson(json);
    expect(event?.eventName, LiveStreamChatEventName.userSendChat);
    expect(event?.message.messageId, messageJson["messageId"]);
    expect(event?.message.username, messageJson["username"]);
    expect(event?.message.text, messageJson["text"]);
    expect(event?.liveStream.id, liveStreamJson["id"]);
  });
}
