import 'package:flutter_test/flutter_test.dart';
import 'package:fw_flutter_sdk/src/models/video_feed_configuration.dart';
import 'package:fw_flutter_sdk/src/utils/model_utils/video_feed_configuration_util.dart';

void main() {
  test('VideoFeedConfigurationUtil toJson', () {
    final configuration = VideoFeedConfiguration(
      backgroundColor: "#c0c0c0",
      cornerRadius: 30,
      title: VideoFeedTitleConfiguration(
        fontSize: 16,
        textColor: "#000000",
        hidden: false,
      ),
      titlePosition: VideoFeedTitlePosition.nested,
      playIcon: VideoFeedPlayIconConfiguration(
        hidden: false,
        iconWidth: 10,
      ),
      showAdBadge: true,
      customLayoutName: "test_custom_layout_name",
      aspectRatio: 0.75,
      contentPadding: VideoFeedContentPadding(
        top: 10,
        right: 15,
        bottom: 11,
        left: 12,
      ),
      itemSpacing: 10,
      enableAutoplay: true,
      gridColumns: 3,
    );
    final json = VideoFeedConfigurationUtil.toJson(configuration);
    expect(json["backgroundColor"], configuration.backgroundColor);
    expect(json["cornerRadius"], configuration.cornerRadius);
    expect(json["title"] is Map<String, dynamic>, true);
    final titleJson = json["title"] as Map<String, dynamic>;
    expect(titleJson["fontSize"], configuration.title?.fontSize);
    expect(titleJson["textColor"], configuration.title?.textColor);
    expect(titleJson["hidden"], configuration.title?.hidden);
    expect(json["titlePosition"],
        configuration.titlePosition.toString().split(".").last);
    expect(json["playIcon"] is Map<String, dynamic>, true);
    final playIconJson = json["playIcon"] as Map<String, dynamic>;
    expect(playIconJson["hidden"], configuration.playIcon?.hidden);
    expect(playIconJson["iconWidth"], configuration.playIcon?.iconWidth);
    expect(json["contentPadding"] is Map<String, dynamic>, true);
    final contentPaddingJson = json["contentPadding"] as Map<String, dynamic>;
    expect(contentPaddingJson["top"], configuration.contentPadding?.top);
    expect(contentPaddingJson["right"], configuration.contentPadding?.right);
    expect(contentPaddingJson["bottom"], configuration.contentPadding?.bottom);
    expect(contentPaddingJson["left"], configuration.contentPadding?.left);
    expect(json["showAdBadge"], configuration.showAdBadge);
    expect(json["customLayoutName"], configuration.customLayoutName);
    expect(json["aspectRatio"], configuration.aspectRatio);
    expect(json["itemSpacing"], configuration.itemSpacing);
    expect(json["enableAutoplay"], configuration.enableAutoplay);
    expect(json["gridColumns"], configuration.gridColumns);
  });
}
